# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2009 Didier Roche
#
# This file is part of Quickly
#
#This program is free software: you can redistribute it and/or modify it 
#under the terms of the GNU General Public License version 3, as published 
#by the Free Software Foundation.

#This program is distributed in the hope that it will be useful, but 
#WITHOUT ANY WARRANTY; without even the implied warranties of 
#MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
#PURPOSE.  See the GNU General Public License for more details.

#You should have received a copy of the GNU General Public License along 
#with this program.  If not, see <http://www.gnu.org/licenses/>.

# THIS IS QUICKLY CONFIGURATION FILE
# Do not touch until you know what you're doing.
# you're warned :)

# quickly version used for project format compatibility
__version__ = '11.04'

# where quickly will head for quickly data (for instance, templates)
# by default, this is ../data, relative to trunk layout
__quickly_data_directory__ = '../data'


